const showLog = false;
let os = '';
function log() {
    showLog && console.log.apply(console, arguments);
}

// note this gets called on extension install + update, but also on chrome update.
function recordInstall(currentAppVersion, currentTime) {

    // They may have existing values. So, we request them.
    chrome.storage.sync.get({
        "appVersionHistory": [],
        "initialAppInstallTime": currentTime
    }, savedVals => {

        // Add the current version to the user's history, if not already there.
        const versions = savedVals.appVersionHistory;
        if (!versions.includes(currentAppVersion)) {
            versions.push(currentAppVersion);
        }

        // Now we write the values back, likely setting them for the first time.
        chrome.storage.sync.set({
            "appVersionHistory": versions,
            "initialAppInstallTime": savedVals.initialAppInstallTime,
            "mostRecentUpdateTime": currentTime,
        }, updateUninstallUrl);

    });
}

function updateUninstallUrl() {
    chrome.storage.sync.get(["appVersionHistory", "initialAppInstallTime", "mostRecentUpdateTime"], syncVals => {
        chrome.storage.local.get({usageStats: {}}, localVals => {
            const manifest = chrome.runtime.getManifest();
            const usageStatsQueryArgs = Object.keys(localVals.usageStats).map(key => `${encodeURIComponent(key)}=${encodeURIComponent(localVals.usageStats[key])}`);

            // chrome imposes a 255 char url limit, so we need to use compact query var names.
            const queryArgs = [
                `app=${encodeURIComponent(manifest.extNameCode)}`,
                `it=${encodeURIComponent(syncVals.initialAppInstallTime)}`,
                `ut=${encodeURIComponent(syncVals.mostRecentUpdateTime)}`,
                `vh=${encodeURIComponent(syncVals.appVersionHistory.join(','))}`,
                // os might not yet have a value, but oh well.
                `os=${encodeURIComponent(os)}`,
                ... usageStatsQueryArgs
            ];

            const url = 'http://rehfeld.us/browser-extensions/uninstall-survey.php?' + queryArgs.join('&');
            // log("setUninstallURL", url);
            chrome.runtime.setUninstallURL(url);
        });
    });
}

chrome.runtime.onInstalled.addListener(details => {
    log("onInstall", details);
    const manifest = chrome.runtime.getManifest();
    recordInstall(manifest.version, unixTimestamp());
});

// Record the os so the content-script can access it.
chrome.runtime.getPlatformInfo(function(info) {
    os = info.os;
    chrome.storage.local.set({
        os
    }, () => {
        // console.log('set os')
    });
});

chrome.storage.onChanged.addListener(updateUninstallUrl);

function unixTimestamp() {
    return Math.floor(Date.now() / 1000);
}

// chrome.commands.onCommand.addListener(function(command) {
//     console.log('Command:', command);
//     // command === 'seek-backwards-short'
//
// });


// window.opt = () => {
//     chrome.runtime.openOptionsPage(function () {
//         log('openOptionsPage', arguments);
//     });
// };

